@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2014  Oliver Burn
+// Copyright (C) 2001-2015 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -16,22 +16,25 @@
 // License along with this library; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ////////////////////////////////////////////////////////////////////////////////
+
 package com.puppycrawl.tools.checkstyle.checks.javadoc;
 
+import java.util.ArrayDeque;
+import java.util.Deque;
+import java.util.List;
+import java.util.Locale;
+import java.util.Set;
+import java.util.regex.Pattern;
+
 import com.google.common.collect.ImmutableSortedSet;
 import com.puppycrawl.tools.checkstyle.api.Check;
 import com.puppycrawl.tools.checkstyle.api.DetailAST;
-import com.puppycrawl.tools.checkstyle.api.FastStack;
 import com.puppycrawl.tools.checkstyle.api.FileContents;
-import com.puppycrawl.tools.checkstyle.api.JavadocTagInfo;
 import com.puppycrawl.tools.checkstyle.api.Scope;
-import com.puppycrawl.tools.checkstyle.api.ScopeUtils;
 import com.puppycrawl.tools.checkstyle.api.TextBlock;
 import com.puppycrawl.tools.checkstyle.api.TokenTypes;
-import com.puppycrawl.tools.checkstyle.checks.CheckUtils;
-import java.util.List;
-import java.util.Set;
-import java.util.regex.Pattern;
+import com.puppycrawl.tools.checkstyle.utils.CheckUtils;
+import com.puppycrawl.tools.checkstyle.utils.ScopeUtils;
 
 /**
  * Custom Checkstyle Check to validate Javadoc.
@@ -39,16 +42,27 @@ import java.util.regex.Pattern;
  * @author Chris Stillwell
  * @author Daniel Grenner
  * @author Travis Schneeberger
- * @version 1.2
  */
 public class JavadocStyleCheck
-    extends Check
-{
+    extends Check {
+
     /** Message property key for the Unclosed HTML message. */
-    private static final String UNCLOSED_HTML = "javadoc.unclosedhtml";
+    public static final String JAVADOC_MISSING = "javadoc.missing";
+
+    /** Message property key for the Unclosed HTML message. */
+    public static final String EMPTY = "javadoc.empty";
+
+    /** Message property key for the Unclosed HTML message. */
+    public static final String NO_PERIOD = "javadoc.noPeriod";
+
+    /** Message property key for the Unclosed HTML message. */
+    public static final String INCOMPLETE_TAG = "javadoc.incompleteTag";
+
+    /** Message property key for the Unclosed HTML message. */
+    public static final String UNCLOSED_HTML = "javadoc.unclosedHtml";
 
     /** Message property key for the Extra HTML message. */
-    private static final String EXTRA_HTML = "javadoc.extrahtml";
+    public static final String EXTRA_HTML = "javadoc.extraHtml";
 
     /** HTML tags that do not require a close tag. */
     private static final Set<String> SINGLE_TAGS = ImmutableSortedSet.of(
@@ -56,7 +70,7 @@ public class JavadocStyleCheck
 
     /** HTML tags that are allowed in java docs.
      * From http://www.w3schools.com/tags/default.asp
-     * The froms and structure tags are not allowed
+     * The forms and structure tags are not allowed
      */
     private static final Set<String> ALLOWED_TAGS = ImmutableSortedSet.of(
             "a", "abbr", "acronym", "address", "area", "b", "bdo", "big",
@@ -68,36 +82,40 @@ public class JavadocStyleCheck
             "thead", "tr", "tt", "u", "ul");
 
     /** The scope to check. */
-    private Scope mScope = Scope.PRIVATE;
+    private Scope scope = Scope.PRIVATE;
 
-    /** the visibility scope where Javadoc comments shouldn't be checked **/
-    private Scope mExcludeScope;
+    /** The visibility scope where Javadoc comments shouldn't be checked. **/
+    private Scope excludeScope;
 
     /** Format for matching the end of a sentence. */
-    private String mEndOfSentenceFormat = "([.?!][ \t\n\r\f<])|([.?!]$)";
+    private String endOfSentenceFormat = "([.?!][ \t\n\r\f<])|([.?!]$)";
 
     /** Regular expression for matching the end of a sentence. */
-    private Pattern mEndOfSentencePattern;
+    private Pattern endOfSentencePattern;
 
     /**
      * Indicates if the first sentence should be checked for proper end of
      * sentence punctuation.
      */
-    private boolean mCheckFirstSentence = true;
+    private boolean checkFirstSentence = true;
 
     /**
      * Indicates if the HTML within the comment should be checked.
      */
-    private boolean mCheckHtml = true;
+    private boolean checkHtml = true;
 
     /**
      * Indicates if empty javadoc statements should be checked.
      */
-    private boolean mCheckEmptyJavadoc;
+    private boolean checkEmptyJavadoc;
 
     @Override
-    public int[] getDefaultTokens()
-    {
+    public int[] getDefaultTokens() {
+        return getAcceptableTokens();
+    }
+
+    @Override
+    public int[] getAcceptableTokens() {
         return new int[] {
             TokenTypes.INTERFACE_DEF,
             TokenTypes.CLASS_DEF,
@@ -113,89 +131,88 @@ public class JavadocStyleCheck
     }
 
     @Override
-    public void visitToken(DetailAST aAST)
-    {
-        if (shouldCheck(aAST)) {
+    public int[] getRequiredTokens() {
+        return getAcceptableTokens();
+    }
+
+    @Override
+    public void visitToken(DetailAST ast) {
+        if (shouldCheck(ast)) {
             final FileContents contents = getFileContents();
             // Need to start searching for the comment before the annotations
             // that may exist. Even if annotations are not defined on the
             // package, the ANNOTATIONS AST is defined.
-            final TextBlock cmt =
-                contents.getJavadocBefore(aAST.getFirstChild().getLineNo());
+            final TextBlock textBlock =
+                contents.getJavadocBefore(ast.getFirstChild().getLineNo());
 
-            checkComment(aAST, cmt);
+            checkComment(ast, textBlock);
         }
     }
 
     /**
      * Whether we should check this node.
-     * @param aAST a given node.
+     * @param ast a given node.
      * @return whether we should check a given node.
      */
-    private boolean shouldCheck(final DetailAST aAST)
-    {
-        if (aAST.getType() == TokenTypes.PACKAGE_DEF) {
-            return getFileContents().inPackageInfo();
-        }
+    private boolean shouldCheck(final DetailAST ast) {
+        boolean check = false;
 
-        if (ScopeUtils.inCodeBlock(aAST)) {
-            return false;
+        if (ast.getType() == TokenTypes.PACKAGE_DEF) {
+            check = getFileContents().inPackageInfo();
         }
+        else if (!ScopeUtils.isInCodeBlock(ast)) {
+            final Scope customScope;
 
-        final Scope declaredScope;
-        if (aAST.getType() == TokenTypes.ENUM_CONSTANT_DEF) {
-            declaredScope = Scope.PUBLIC;
+            if (ScopeUtils.isInInterfaceOrAnnotationBlock(ast)
+                    || ast.getType() == TokenTypes.ENUM_CONSTANT_DEF) {
+                customScope = Scope.PUBLIC;
+            }
+            else {
+                customScope = ScopeUtils.getScopeFromMods(ast.findFirstToken(TokenTypes.MODIFIERS));
+            }
+            final Scope surroundingScope = ScopeUtils.getSurroundingScope(ast);
+
+            check = customScope.isIn(scope)
+                    && (surroundingScope == null || surroundingScope.isIn(scope))
+                    && (excludeScope == null
+                        || !customScope.isIn(excludeScope)
+                        || surroundingScope != null
+                            && !surroundingScope.isIn(excludeScope));
         }
-        else {
-            declaredScope = ScopeUtils.getScopeFromMods(
-                aAST.findFirstToken(TokenTypes.MODIFIERS));
-        }
-
-        final Scope scope =
-            ScopeUtils.inInterfaceOrAnnotationBlock(aAST)
-            ? Scope.PUBLIC : declaredScope;
-        final Scope surroundingScope = ScopeUtils.getSurroundingScope(aAST);
-
-        return scope.isIn(mScope)
-            && ((surroundingScope == null) || surroundingScope.isIn(mScope))
-            && ((mExcludeScope == null)
-                || !scope.isIn(mExcludeScope)
-                || ((surroundingScope != null)
-                && !surroundingScope.isIn(mExcludeScope)));
+        return check;
     }
 
     /**
-     * Performs the various checks agains the Javadoc comment.
+     * Performs the various checks against the Javadoc comment.
      *
-     * @param aAST the AST of the element being documented
-     * @param aComment the source lines that make up the Javadoc comment.
+     * @param ast the AST of the element being documented
+     * @param comment the source lines that make up the Javadoc comment.
      *
-     * @see #checkFirstSentence(DetailAST, TextBlock)
-     * @see #checkHtml(DetailAST, TextBlock)
+     * @see #checkFirstSentenceEnding(DetailAST, TextBlock)
+     * @see #checkHtmlTags(DetailAST, TextBlock)
      */
-    private void checkComment(final DetailAST aAST, final TextBlock aComment)
-    {
-        if (aComment == null) {
+    private void checkComment(final DetailAST ast, final TextBlock comment) {
+        if (comment == null) {
             /*checking for missing docs in JavadocStyleCheck is not consistent
             with the rest of CheckStyle...  Even though, I didn't think it
-            made sense to make another csheck just to ensure that the
+            made sense to make another check just to ensure that the
             package-info.java file actually contains package Javadocs.*/
             if (getFileContents().inPackageInfo()) {
-                log(aAST.getLineNo(), "javadoc.missing");
+                log(ast.getLineNo(), JAVADOC_MISSING);
             }
             return;
         }
 
-        if (mCheckFirstSentence) {
-            checkFirstSentence(aAST, aComment);
+        if (checkFirstSentence) {
+            checkFirstSentenceEnding(ast, comment);
         }
 
-        if (mCheckHtml) {
-            checkHtml(aAST, aComment);
+        if (checkHtml) {
+            checkHtmlTags(ast, comment);
         }
 
-        if (mCheckEmptyJavadoc) {
-            checkEmptyJavadoc(aComment);
+        if (checkEmptyJavadoc) {
+            checkJavadocIsNotEmpty(comment);
         }
     }
 
@@ -206,45 +223,41 @@ public class JavadocStyleCheck
      * HTML element, or the end of string. This method ignores {_AT_inheritDoc}
      * comments for TokenTypes that are valid for {_AT_inheritDoc}.
      *
-     * @param aAST the current node
-     * @param aComment the source lines that make up the Javadoc comment.
+     * @param ast the current node
+     * @param comment the source lines that make up the Javadoc comment.
      */
-    private void checkFirstSentence(final DetailAST aAST, TextBlock aComment)
-    {
-        final String commentText = getCommentText(aComment.getText());
+    private void checkFirstSentenceEnding(final DetailAST ast, TextBlock comment) {
+        final String commentText = getCommentText(comment.getText());
 
-        if ((commentText.length() != 0)
+        if (!commentText.isEmpty()
             && !getEndOfSentencePattern().matcher(commentText).find()
-            && !("{@inheritDoc}".equals(commentText)
-            && JavadocTagInfo.INHERIT_DOC.isValidOn(aAST)))
-        {
-            log(aComment.getStartLineNo(), "javadoc.noperiod");
+            && !(commentText.startsWith("{@inheritDoc}")
+            && JavadocTagInfo.INHERIT_DOC.isValidOn(ast))) {
+            log(comment.getStartLineNo(), NO_PERIOD);
         }
     }
 
     /**
      * Checks that the Javadoc is not empty.
      *
-     * @param aComment the source lines that make up the Javadoc comment.
+     * @param comment the source lines that make up the Javadoc comment.
      */
-    private void checkEmptyJavadoc(TextBlock aComment)
-    {
-        final String commentText = getCommentText(aComment.getText());
+    private void checkJavadocIsNotEmpty(TextBlock comment) {
+        final String commentText = getCommentText(comment.getText());
 
-        if (commentText.length() == 0) {
-            log(aComment.getStartLineNo(), "javadoc.empty");
+        if (commentText.isEmpty()) {
+            log(comment.getStartLineNo(), EMPTY);
         }
     }
 
     /**
      * Returns the comment text from the Javadoc.
-     * @param aComments the lines of Javadoc.
+     * @param comments the lines of Javadoc.
      * @return a comment text String.
      */
-    private String getCommentText(String[] aComments)
-    {
-        final StringBuffer buffer = new StringBuffer();
-        for (final String line : aComments) {
+    private static String getCommentText(String... comments) {
+        final StringBuilder builder = new StringBuilder();
+        for (final String line : comments) {
             final int textStart = findTextStart(line);
 
             if (textStart != -1) {
@@ -252,68 +265,67 @@ public class JavadocStyleCheck
                     //we have found the tag section
                     break;
                 }
-                buffer.append(line.substring(textStart));
-                trimTail(buffer);
-                buffer.append('\n');
+                builder.append(line.substring(textStart));
+                trimTail(builder);
+                builder.append('\n');
             }
         }
 
-        return buffer.toString().trim();
+        return builder.toString().trim();
     }
 
     /**
      * Finds the index of the first non-whitespace character ignoring the
      * Javadoc comment start and end strings (&#47** and *&#47) as well as any
      * leading asterisk.
-     * @param aLine the Javadoc comment line of text to scan.
+     * @param line the Javadoc comment line of text to scan.
      * @return the int index relative to 0 for the start of text
      *         or -1 if not found.
      */
-    private int findTextStart(String aLine)
-    {
+    private static int findTextStart(String line) {
         int textStart = -1;
-        for (int i = 0; i < aLine.length(); i++) {
-            if (!Character.isWhitespace(aLine.charAt(i))) {
-                if (aLine.regionMatches(i, "/**", 0, "/**".length())) {
+        for (int i = 0; i < line.length();) {
+            if (!Character.isWhitespace(line.charAt(i))) {
+                if (line.regionMatches(i, "/**", 0, "/**".length())) {
                     i += 2;
                 }
-                else if (aLine.regionMatches(i, "*/", 0, 2)) {
+                else if (line.regionMatches(i, "*/", 0, 2)) {
                     i++;
                 }
-                else if (aLine.charAt(i) != '*') {
+                else if (line.charAt(i) != '*') {
                     textStart = i;
                     break;
                 }
             }
+            i++;
         }
         return textStart;
     }
 
     /**
      * Trims any trailing whitespace or the end of Javadoc comment string.
-     * @param aBuffer the StringBuffer to trim.
+     * @param builder the StringBuilder to trim.
      */
-    private void trimTail(StringBuffer aBuffer)
-    {
-        for (int i = aBuffer.length() - 1; i >= 0; i--) {
-            if (Character.isWhitespace(aBuffer.charAt(i))) {
-                aBuffer.deleteCharAt(i);
+    private static void trimTail(StringBuilder builder) {
+        int index = builder.length() - 1;
+        while (true) {
+            if (Character.isWhitespace(builder.charAt(index))) {
+                builder.deleteCharAt(index);
             }
-            else if ((i > 0)
-                     && (aBuffer.charAt(i - 1) == '*')
-                     && (aBuffer.charAt(i) == '/'))
-            {
-                aBuffer.deleteCharAt(i);
-                aBuffer.deleteCharAt(i - 1);
-                i--;
-                while (aBuffer.charAt(i - 1) == '*') {
-                    aBuffer.deleteCharAt(i - 1);
-                    i--;
+            else if (builder.charAt(index) == '/'
+                    && builder.charAt(index - 1) == '*') {
+                builder.deleteCharAt(index);
+                builder.deleteCharAt(index - 1);
+                index--;
+                while (builder.charAt(index - 1) == '*') {
+                    builder.deleteCharAt(index - 1);
+                    index--;
                 }
             }
             else {
                 break;
             }
+            index--;
         }
     }
 
@@ -322,44 +334,34 @@ public class JavadocStyleCheck
      * tag or a close tag that has no previous open tag.  This code was
      * primarily copied from the DocCheck checkHtml method.
      *
-     * @param aAST the node with the Javadoc
-     * @param aComment the <code>TextBlock</code> which represents
+     * @param ast the node with the Javadoc
+     * @param comment the {@code TextBlock} which represents
      *                 the Javadoc comment.
      */
-    private void checkHtml(final DetailAST aAST, final TextBlock aComment)
-    {
-        final int lineno = aComment.getStartLineNo();
-        final FastStack<HtmlTag> htmlStack = FastStack.newInstance();
-        final String[] text = aComment.getText();
-        final List<String> typeParameters =
-            CheckUtils.getTypeParameterNames(aAST);
+    private void checkHtmlTags(final DetailAST ast, final TextBlock comment) {
+        final int lineNo = comment.getStartLineNo();
+        final Deque<HtmlTag> htmlStack = new ArrayDeque<>();
+        final String[] text = comment.getText();
 
-        TagParser parser = null;
-        parser = new TagParser(text, lineno);
+        final TagParser parser = new TagParser(text, lineNo);
 
         while (parser.hasNextTag()) {
             final HtmlTag tag = parser.nextTag();
 
             if (tag.isIncompleteTag()) {
-                log(tag.getLineno(), "javadoc.incompleteTag",
-                    text[tag.getLineno() - lineno]);
+                log(tag.getLineNo(), INCOMPLETE_TAG,
+                    text[tag.getLineNo() - lineNo]);
                 return;
             }
             if (tag.isClosedTag()) {
                 //do nothing
                 continue;
             }
-            if (!tag.isCloseTag()) {
-                //We only push html tags that are allowed
-                if (isAllowedTag(tag)) {
-                    htmlStack.push(tag);
-                }
-            }
-            else {
+            if (tag.isCloseTag()) {
                 // We have found a close tag.
                 if (isExtraHtml(tag.getId(), htmlStack)) {
                     // No corresponding open tag was found on the stack.
-                    log(tag.getLineno(),
+                    log(tag.getLineNo(),
                         tag.getPosition(),
                         EXTRA_HTML,
                         tag);
@@ -370,17 +372,24 @@ public class JavadocStyleCheck
                     checkUnclosedTags(htmlStack, tag.getId());
                 }
             }
+            else {
+                //We only push html tags that are allowed
+                if (isAllowedTag(tag)) {
+                    htmlStack.push(tag);
+                }
+            }
         }
 
         // Identify any tags left on the stack.
-        String lastFound = ""; // Skip multiples, like <b>...<b>
-        for (final HtmlTag htag : htmlStack) {
-            if (!isSingleTag(htag)
-                && !htag.getId().equals(lastFound)
-                && !typeParameters.contains(htag.getId()))
-            {
-                log(htag.getLineno(), htag.getPosition(), UNCLOSED_HTML, htag);
-                lastFound = htag.getId();
+        // Skip multiples, like <b>...<b>
+        String lastFound = "";
+        final List<String> typeParameters = CheckUtils.getTypeParameterNames(ast);
+        for (final HtmlTag htmlTag : htmlStack) {
+            if (!isSingleTag(htmlTag)
+                && !htmlTag.getId().equals(lastFound)
+                && !typeParameters.contains(htmlTag.getId())) {
+                log(htmlTag.getLineNo(), htmlTag.getPosition(), UNCLOSED_HTML, htmlTag);
+                lastFound = htmlTag.getId();
             }
         }
     }
@@ -391,34 +400,34 @@ public class JavadocStyleCheck
      * tag on the stack.  Any tags, except single tags, that were opened
      * (pushed on the stack) after the token are missing a close.
      *
-     * @param aHtmlStack the stack of opened HTML tags.
-     * @param aToken the current HTML tag name that has been closed.
+     * @param htmlStack the stack of opened HTML tags.
+     * @param token the current HTML tag name that has been closed.
      */
-    private void checkUnclosedTags(FastStack<HtmlTag> aHtmlStack, String aToken)
-    {
-        final FastStack<HtmlTag> unclosedTags = FastStack.newInstance();
-        HtmlTag lastOpenTag = aHtmlStack.pop();
-        while (!aToken.equalsIgnoreCase(lastOpenTag.getId())) {
+    private void checkUnclosedTags(Deque<HtmlTag> htmlStack, String token) {
+        final Deque<HtmlTag> unclosedTags = new ArrayDeque<>();
+        HtmlTag lastOpenTag = htmlStack.pop();
+        while (!token.equalsIgnoreCase(lastOpenTag.getId())) {
             // Find unclosed elements. Put them on a stack so the
             // output order won't be back-to-front.
             if (isSingleTag(lastOpenTag)) {
-                lastOpenTag = aHtmlStack.pop();
+                lastOpenTag = htmlStack.pop();
             }
             else {
                 unclosedTags.push(lastOpenTag);
-                lastOpenTag = aHtmlStack.pop();
+                lastOpenTag = htmlStack.pop();
             }
         }
 
         // Output the unterminated tags, if any
-        String lastFound = ""; // Skip multiples, like <b>..<b>
+        // Skip multiples, like <b>..<b>
+        String lastFound = "";
         for (final HtmlTag htag : unclosedTags) {
             lastOpenTag = htag;
             if (lastOpenTag.getId().equals(lastFound)) {
                 continue;
             }
             lastFound = lastOpenTag.getId();
-            log(lastOpenTag.getLineno(),
+            log(lastOpenTag.getLineNo(),
                 lastOpenTag.getPosition(),
                 UNCLOSED_HTML,
                 lastOpenTag);
@@ -428,47 +437,44 @@ public class JavadocStyleCheck
     /**
      * Determines if the HtmlTag is one which does not require a close tag.
      *
-     * @param aTag the HtmlTag to check.
-     * @return <code>true</code> if the HtmlTag is a single tag.
+     * @param tag the HtmlTag to check.
+     * @return {@code true} if the HtmlTag is a single tag.
      */
-    private boolean isSingleTag(HtmlTag aTag)
-    {
+    private static boolean isSingleTag(HtmlTag tag) {
         // If its a singleton tag (<p>, <br>, etc.), ignore it
         // Can't simply not put them on the stack, since singletons
         // like <dt> and <dd> (unhappily) may either be terminated
         // or not terminated. Both options are legal.
-        return SINGLE_TAGS.contains(aTag.getId().toLowerCase());
+        return SINGLE_TAGS.contains(tag.getId().toLowerCase(Locale.ENGLISH));
     }
 
     /**
      * Determines if the HtmlTag is one which is allowed in a javadoc.
      *
-     * @param aTag the HtmlTag to check.
-     * @return <code>true</code> if the HtmlTag is an allowed html tag.
+     * @param tag the HtmlTag to check.
+     * @return {@code true} if the HtmlTag is an allowed html tag.
      */
-    private boolean isAllowedTag(HtmlTag aTag)
-    {
-        return ALLOWED_TAGS.contains(aTag.getId().toLowerCase());
+    private static boolean isAllowedTag(HtmlTag tag) {
+        return ALLOWED_TAGS.contains(tag.getId().toLowerCase(Locale.ENGLISH));
     }
 
     /**
      * Determines if the given token is an extra HTML tag. This indicates that
      * a close tag was found that does not have a corresponding open tag.
      *
-     * @param aToken an HTML tag id for which a close was found.
-     * @param aHtmlStack a Stack of previous open HTML tags.
-     * @return <code>false</code> if a previous open tag was found
+     * @param token an HTML tag id for which a close was found.
+     * @param htmlStack a Stack of previous open HTML tags.
+     * @return {@code false} if a previous open tag was found
      *         for the token.
      */
-    private boolean isExtraHtml(String aToken, FastStack<HtmlTag> aHtmlStack)
-    {
+    private static boolean isExtraHtml(String token, Deque<HtmlTag> htmlStack) {
         boolean isExtra = true;
-        for (final HtmlTag td : aHtmlStack) {
+        for (final HtmlTag td : htmlStack) {
             // Loop, looking for tags that are closed.
             // The loop is needed in case there are unclosed
             // tags on the stack. In that case, the stack would
             // not be empty, but this tag would still be extra.
-            if (aToken.equalsIgnoreCase(td.getId())) {
+            if (token.equalsIgnoreCase(td.getId())) {
                 isExtra = false;
                 break;
             }
@@ -479,29 +485,26 @@ public class JavadocStyleCheck
 
     /**
      * Sets the scope to check.
-     * @param aFrom string to get the scope from
+     * @param from string to get the scope from
      */
-    public void setScope(String aFrom)
-    {
-        mScope = Scope.getInstance(aFrom);
+    public void setScope(String from) {
+        scope = Scope.getInstance(from);
     }
 
     /**
      * Set the excludeScope.
-     * @param aScope a <code>String</code> value
+     * @param excludeScope a {@code String} value
      */
-    public void setExcludeScope(String aScope)
-    {
-        mExcludeScope = Scope.getInstance(aScope);
+    public void setExcludeScope(String excludeScope) {
+        this.excludeScope = Scope.getInstance(excludeScope);
     }
 
     /**
      * Set the format for matching the end of a sentence.
-     * @param aFormat format for matching the end of a sentence.
+     * @param format format for matching the end of a sentence.
      */
-    public void setEndOfSentenceFormat(String aFormat)
-    {
-        mEndOfSentenceFormat = aFormat;
+    public void setEndOfSentenceFormat(String format) {
+        endOfSentenceFormat = format;
     }
 
     /**
@@ -509,39 +512,35 @@ public class JavadocStyleCheck
      *
      * @return a regular expression for matching the end of a sentence.
      */
-    private Pattern getEndOfSentencePattern()
-    {
-        if (mEndOfSentencePattern == null) {
-            mEndOfSentencePattern = Pattern.compile(mEndOfSentenceFormat);
+    private Pattern getEndOfSentencePattern() {
+        if (endOfSentencePattern == null) {
+            endOfSentencePattern = Pattern.compile(endOfSentenceFormat);
         }
-        return mEndOfSentencePattern;
+        return endOfSentencePattern;
     }
 
     /**
      * Sets the flag that determines if the first sentence is checked for
      * proper end of sentence punctuation.
-     * @param aFlag <code>true</code> if the first sentence is to be checked
+     * @param flag {@code true} if the first sentence is to be checked
      */
-    public void setCheckFirstSentence(boolean aFlag)
-    {
-        mCheckFirstSentence = aFlag;
+    public void setCheckFirstSentence(boolean flag) {
+        checkFirstSentence = flag;
     }
 
     /**
      * Sets the flag that determines if HTML checking is to be performed.
-     * @param aFlag <code>true</code> if HTML checking is to be performed.
+     * @param flag {@code true} if HTML checking is to be performed.
      */
-    public void setCheckHtml(boolean aFlag)
-    {
-        mCheckHtml = aFlag;
+    public void setCheckHtml(boolean flag) {
+        checkHtml = flag;
     }
 
     /**
-     * Sets the flag that determines if empty JavaDoc checking should be done.
-     * @param aFlag <code>true</code> if empty JavaDoc checking should be done.
+     * Sets the flag that determines if empty Javadoc checking should be done.
+     * @param flag {@code true} if empty Javadoc checking should be done.
      */
-    public void setCheckEmptyJavadoc(boolean aFlag)
-    {
-        mCheckEmptyJavadoc = aFlag;
+    public void setCheckEmptyJavadoc(boolean flag) {
+        checkEmptyJavadoc = flag;
     }
 }
