@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2014  Oliver Burn
+// Copyright (C) 2001-2015 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -16,18 +16,17 @@
 // License along with this library; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ////////////////////////////////////////////////////////////////////////////////
+
 package com.puppycrawl.tools.checkstyle.checks.whitespace;
 
 /**
  * Represents the options for wrapping on an operator.
  *
  * @author Rick Giles
- * @version 1.0
  */
-public enum WrapOption
-{
+public enum WrapOption {
     /** Require that the token is on a new line. */
     NL,
     /** Require that the token is at the end of the line. */
-    EOL;
+    EOL
 }
