@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2014  Oliver Burn
+// Copyright (C) 2001-2015 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -16,19 +16,26 @@
 // License along with this library; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ////////////////////////////////////////////////////////////////////////////////
+
 package com.puppycrawl.tools.checkstyle.api;
 
+import static com.puppycrawl.tools.checkstyle.TestUtils.assertUtilsClassHasPrivateConstructor;
 import static org.junit.Assert.assertEquals;
 
 import org.junit.Test;
 
-public class TokenTypesTest
-{
+import com.puppycrawl.tools.checkstyle.utils.TokenUtils;
+
+public class TokenTypesTest {
     @Test
-    public void testGetShortDescription()
-    {
+    public void testGetShortDescription() {
         assertEquals("short description for EQUAL",
-                "The <code>==</code> (equal) operator.", TokenTypes
+                "The <code>==</code> (equal) operator.", TokenUtils
                         .getShortDescription("EQUAL"));
     }
+
+    @Test
+    public void testIsProperUtilsClass() throws ReflectiveOperationException {
+        assertUtilsClassHasPrivateConstructor(TokenTypes.class);
+    }
 }
